@@ -4,8 +4,9 @@ Todo:
 - Add ability to extend text_explainability vocab per language
 """
 
-from text_explainability.internationalization import translate_string, translate_list, set_locale, get_locale
-
+from text_explainability.internationalization import (get_locale, set_locale,
+                                                      translate_list,
+                                                      translate_string)
 
 LOCALE_MAP = {'br': 'pt_BR',
               'cs': 'cs_CZ',
