@@ -1,18 +1,18 @@
 """Apply perturbations to TextInstances and/or strings, generating one or many new instances."""
 
 
-import numpy as np
-import itertools
 import copy
-from typing import Tuple, Dict, List, Optional, Callable, Sequence, Union, Iterable
-from nlpaug.base_augmenter import Augmenter
+import itertools
+from typing import (Callable, Dict, Iterable, List, Optional, Sequence, Tuple,
+                    Union)
 
-from instancelib.instances.text import TextInstance, MemoryTextInstance
+import numpy as np
+from instancelib.instances.text import MemoryTextInstance, TextInstance
 from instancelib.typehints import KT, LT
-
-from text_explainability.default import Readable
+from nlpaug.base_augmenter import Augmenter
 from text_explainability.decorators import text_instance
-from text_explainability.utils import default_tokenizer, default_detokenizer
+from text_explainability.default import Readable
+from text_explainability.utils import default_detokenizer, default_tokenizer
 
 
 def oneway_dictionary_mapping(instance: TextInstance,
@@ -44,8 +44,9 @@ def one_to_one_dictionary_mapping(instance: TextInstance,
                                   label_to: LT,
                                   tokenizer,
                                   detokenizer):
-    return list(oneway_dictionary_mapping(instance, dictionary, label_from=label_from, label_to=label_to,
-                                          tokenizer=tokenizer, detokenizer=detokenizer, n=1))[0]
+    res = oneway_dictionary_mapping(instance, dictionary, label_from=label_from, label_to=label_to,
+                                    tokenizer=tokenizer, detokenizer=detokenizer, n=1)
+    return list(res) if res is not None else res
 
 
 def one_to_many_dictionary_mapping(instance: TextInstance,
